<?xml version="1.0" encoding="UTF-8"?>
<!-- *************************************
This stylesheet creates a table corresponding to the annotation of adjacency pairs, i.e. pairs of 
dialogue acts that are related (e.g. question/answer); the first one is the source and the second one
the target.
The external files to be used are the ones with the speaker codes and the types of APs.
Format of the table: 
	meeting_id, annotator, ap_id, ap_type, ap_type_gloss, 
	source_speaker_id, source_nxt_speaker, source_annotator, source_da_id,
	target_speaker_id, target_nxt_speaker, target_annotator, target_da_id
 
Andrei Popescu-Belis, June 2006
****************************************-->
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:nite="http://nite.sourceforge.net/">
	<xsl:output method="text" version="1.0" encoding="ISO-8859-1" indent="no"/>
	<xsl:param name="speakerfile">file://C:\Documents and Settings\Andrei Popescu-Belis\Mes documents\IM2phase2\AMI-data-private\corpusResources\meetings.xml</xsl:param>
	<xsl:param name="speakerlist" select="document($speakerfile)"/>
	<xsl:param name="aptypesfile">file://C:\Documents and Settings\Andrei Popescu-Belis\Mes documents\IM2phase2\AMI-data-private\ontologies\ap-types.xml</xsl:param>
	<xsl:param name="aptypes" select="document($aptypesfile)"/>

	<!-- ************************************************ -->
	<xsl:template match="nite:root">
		<xsl:param name="meeting_id" select="substring-before(@nite:id,'.')"/>
		<xsl:param name="meeting_speakers2" select="$speakerlist//meeting[@observation = $meeting_id]"/>
		<xsl:apply-templates select="adjacency-pair">
			<xsl:with-param name="meeting_speakers" select="$meeting_speakers2"/>
		</xsl:apply-templates>
	</xsl:template>
	<!-- ************************************************ -->
	<xsl:template match="adjacency-pair">
		<xsl:param name="meeting_speakers"/>
		<xsl:param name="ap_type" select="substring-before(substring-after(./nite:pointer[@role='type']/@href,'#id('),')')"/>
		<xsl:param name="source" select="substring-before(substring-after(./nite:pointer[@role='source']/@href,'#id('),')')"/> 
		<!-- example: ES2003b.C.dialog-act.vkaraisk.1 -->
		<xsl:param name="target" select="substring-before(substring-after(./nite:pointer[@role='target']/@href,'#id('),')')"/> 
		<!-- example: ES2003b.B.dialog-act.vkaraisk.1 -->
	<xsl:if test="./nite:pointer[@role='target']"> <!-- because some links lack both source and target -->
		<!-- meeting_id -->
		<xsl:value-of select="substring-before(@nite:id,'.')"/> <!-- example: ES2003b.adjacency-pairs.vkaraisk.1 -->
		<xsl:text>	</xsl:text>
		<!-- annotator -->
		<xsl:value-of select="substring-before(substring-after(substring-after(@nite:id,'.'),'.'),'.')"/>
		<xsl:text>	</xsl:text>
		<!-- ap_id -->
		<xsl:value-of select="substring-after(substring-after(substring-after(@nite:id,'.'),'.'),'.')"/>
		<xsl:text>	</xsl:text>
		<!-- ap_type -->
		<xsl:value-of select="$aptypes//ap-type[@nite:id=$ap_type]/@name"/>
		<xsl:text>	</xsl:text>
		<!-- ap_type_gloss -->
		<xsl:value-of select="$aptypes//ap-type[@nite:id=$ap_type]/@gloss"/>
		<xsl:text>	</xsl:text>
		<!-- Sometimes there is no source, if the real source is too general (more than one utterance) or non verbal -->
		<xsl:choose>
			<xsl:when test="./nite:pointer[@role='source']">
				<!-- source_speaker_id -->
				<xsl:value-of select="$meeting_speakers/speaker[@nxt_agent = substring-before(substring-after($source,'.'),'.')]/@global_name"/>
				<xsl:text>	</xsl:text>
				<!-- source_nxt_speaker -->
				<xsl:value-of select="substring-before(substring-after($source,'.'),'.')"/>
				<xsl:text>	</xsl:text>
				<!-- source_annotator -->
				<xsl:value-of select="substring-before(substring-after(substring-after(substring-after($source,'.'),'.'),'.'),'.')"/>
				<xsl:text>	</xsl:text>
				<!-- source_da_id -->
				<xsl:value-of select="substring-after(substring-after(substring-after(substring-after($source,'.'),'.'),'.'),'.')"/>
				<xsl:text>	</xsl:text>
			</xsl:when>
			<xsl:otherwise><xsl:text>nil	nil	nil	0	</xsl:text></xsl:otherwise>
		</xsl:choose>
		<!-- target_speaker_id -->
		<xsl:value-of select="$meeting_speakers/speaker[@nxt_agent = substring-before(substring-after($target,'.'),'.')]/@global_name"/>
		<xsl:text>	</xsl:text>
		<!-- target_nxt_speaker -->
		<xsl:value-of select="substring-before(substring-after($target,'.'),'.')"/>
		<xsl:text>	</xsl:text>
		<!-- target_annotator -->
		<xsl:value-of select="substring-before(substring-after(substring-after(substring-after($target,'.'),'.'),'.'),'.')"/>
		<xsl:text>	</xsl:text>
		<!-- target_da_id -->
		<xsl:value-of select="substring-after(substring-after(substring-after(substring-after($target,'.'),'.'),'.'),'.')"/>
		<xsl:text>
</xsl:text>
	</xsl:if></xsl:template>
</xsl:stylesheet>
