<?xml version="1.0" encoding="UTF-8"?>
<!-- This stylesheet creates a table corresponding to the argument structures using the files: XX1234z.N.argumentstructs.xml 
      Format of the table: meeting_id, speaker_id, nxt_speaker, ae_id, annotator, ae_name, ae_gloss, starttime, endtime, startword, endword, words 
      *************************************
      Andrei Popescu-Belis, Feb 2007
-->
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:nite="http://nite.sourceforge.net/">
	<xsl:output method="text" version="1.0" encoding="ISO-8859-1" indent="no"/>
	<xsl:param name="wordfile">file://C:\Documents and Settings\Andrei Popescu-Belis\Mes documents\IM2phase2\DATA\AMI-data-020207\words\ES2002a.B.words.xml</xsl:param>
	<xsl:param name="wordfilecontents" select="document($wordfile)"/>
	<xsl:param name="aetypesfile">file://C:\Documents and Settings\Andrei Popescu-Belis\Mes documents\IM2phase2\DATA\AMI-data-020207\ontologies\ae-types.xml</xsl:param>
	<xsl:param name="aetypes" select="document($aetypesfile)"/>
	<xsl:param name="speakerfile">file://C:\Documents and Settings\Andrei Popescu-Belis\Mes documents\IM2phase2\DATA\AMI-data-020207\corpusResources\meetings.xml</xsl:param>
	<xsl:param name="speakerlist" select="document($speakerfile)"/>
	<!-- ************************************************ -->
	<xsl:template match="nite:root">
		<xsl:param name="meeting_id" select="substring-before(@nite:id,'.')"/>
		<xsl:param name="nxt_speaker" select="substring-before(substring-after(@nite:id,'.'),'.')"/>
		<xsl:apply-templates select="ae">
			<xsl:with-param name="speaker_id" select="$speakerlist//meeting[@observation = $meeting_id]/speaker[@nxt_agent = $nxt_speaker]/@global_name"/>
		</xsl:apply-templates>
	</xsl:template>
	<!-- ************************************************ -->
	<xsl:template match="ae">
		<xsl:param name="speaker_id"/> 
		<xsl:param name="seg_id" select="@nite:id"/>
		<!-- meeting_id -->
		<xsl:value-of select="substring-before(@nite:id,'.')"/>
		<!-- nite:id example: ES2002a.A.argumentstructs.Erik.1 but also ES2002a.A.argumentstructs.10 -->
		<xsl:text>	</xsl:text>
		<!-- speaker_id -->
		<xsl:value-of select="$speaker_id"/>
		<xsl:text>	</xsl:text>
		<!-- nxt_speaker -->
		<xsl:value-of select="substring-before(substring-after(@nite:id,'.'),'.')"/>
		<xsl:text>	</xsl:text>
		<!-- annotator is SOMETIMES MISSING  -->
		<xsl:choose>
			<xsl:when test="(substring-before(substring-after(substring-after(substring-after(@nite:id,'.'),'.'),'.'),'.')!='')">
				<!-- annotator -->
				<xsl:value-of select="substring-before(substring-after(substring-after(substring-after(@nite:id,'.'),'.'),'.'),'.')"/>
				<xsl:text>	</xsl:text>
				<!-- ae_id -->
				<xsl:value-of select="substring-after(substring-after(substring-after(substring-after(@nite:id,'.'),'.'),'.'),'.')"/>
				<xsl:text>	</xsl:text>
			</xsl:when>
			<xsl:otherwise>
				<!-- annotator -->
				<xsl:text>AMIdefault	</xsl:text>
				<!-- ae_id -->
				<xsl:value-of select="substring-after(substring-after(substring-after(@nite:id,'.'),'.'),'.')"/>
				<xsl:text>	</xsl:text>
			</xsl:otherwise>
		</xsl:choose>
		<xsl:call-template name="ae-names">
			<xsl:with-param name="niteid" select="substring-before(substring-after(nite:pointer[@role='type']/@href,'ae-types.xml#id('),')')"/>
		</xsl:call-template>
		<!-- From time to time, there are two <nite:child> after <nite:pointer> mainly because the arg unit contains a disfluency marker,
			 so the unit is cut into fragments of continuous words, e.g. words1509..words1517 and words1519..words1524 because word1518
			 is a disfluency marker. Here, we test this and adjust the start and end accordingly to produce only one chunk of words/disfluencies
			 basically by looking at the first <nite:child> for 'start' and at the second <nite:child> for 'end'-->
		<xsl:choose>
			<xsl:when test="contains(nite:child[1]/@href,'..') and contains(nite:child[position()=last()]/@href,'..')">
				<xsl:call-template name="words">
					<xsl:with-param name="start" select="substring-before(substring-after(substring-after(nite:child[1]/@href,'#id('),'words'),')..')"/>
					<xsl:with-param name="end" select="substring-before(substring-after(substring-after(nite:child[position()=last()]/@href,'..id('),'words'),')')"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:when test="contains(nite:child[1]/@href,'..') and not(contains(nite:child[position()=last()]/@href,'..'))">
				<xsl:call-template name="words">
					<xsl:with-param name="start" select="substring-before(substring-after(substring-after(nite:child[1]/@href,'#id('),'words'),')..')"/>
					<xsl:with-param name="end" select="substring-before(substring-after(substring-after(nite:child[position()=last()]/@href,'#id('),'words'),')')"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:when test="not(contains(nite:child[1]/@href,'..')) and contains(nite:child[position()=last()]/@href,'..')">
				<xsl:call-template name="words">
					<xsl:with-param name="start" select="substring-before(substring-after(substring-after(nite:child[1]/@href,'#id('),'words'),')')"/>
					<xsl:with-param name="end" select="substring-before(substring-after(substring-after(nite:child[position()=last()]/@href,'..id('),'words'),')')"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="words">
					<xsl:with-param name="start" select="substring-before(substring-after(substring-after(nite:child/@href,'#id('),'words'),')')"/>
					<xsl:with-param name="end" select="substring-before(substring-after(substring-after(nite:child/@href,'#id('),'words'),')')"/>
				</xsl:call-template>
			</xsl:otherwise>
		</xsl:choose>
		<xsl:text>&#xA;</xsl:text>
	</xsl:template>
	<!-- ************************************************ -->
	<xsl:template name="ae-names">
		<xsl:param name="niteid"/>
		<!-- encoded as ae_N -->
		<xsl:choose>
			<xsl:when test="substring-after($niteid,'_') &lt;= 5">
				<!-- ae_name -->
				<xsl:value-of select="$aetypes//ae-type[@nite:id=$niteid]/@name"/>
				<xsl:text>	</xsl:text>
				<!-- ae_gloss -->
				<xsl:value-of select="$aetypes//ae-type[@nite:id=$niteid]/@gloss"/>
				<xsl:text>	</xsl:text>
			</xsl:when>
			<xsl:otherwise>
				<xsl:text>XXX	unspecified	</xsl:text>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<!-- ************************************************ -->
	<xsl:template name="words">
		<xsl:param name="start"/>
		<xsl:param name="end"/>
		<!-- starttime -->
		<xsl:value-of select="$wordfilecontents//*[$start = number(substring-after(@nite:id,'words'))]/@starttime"/>
		<xsl:text>	</xsl:text>
		<!-- endtime -->
		<xsl:value-of select="$wordfilecontents//*[$end = number(substring-after(@nite:id,'words'))]/@endtime"/>
		<xsl:text>	</xsl:text>
		<!-- startword -->
		<xsl:value-of select="$start"/>
		<xsl:text>	</xsl:text>
		<!-- endword -->
		<xsl:value-of select="$end"/>
		<xsl:text>	</xsl:text>
		<!-- words -->
		<xsl:apply-templates select="$wordfilecontents//*[($start &lt;= number(substring-after(@nite:id,'words'))) and (number(substring-after(@nite:id,'words')) &lt;= $end)]"/>
	</xsl:template>
	<!-- ************************************************ -->
	<xsl:template match="w|disfmarker|vocalsound|gap">
		<xsl:choose>
			<xsl:when test="position()=1"/>
			<xsl:otherwise>
				<xsl:text> </xsl:text>
			</xsl:otherwise>
		</xsl:choose>
		<xsl:choose>
			<xsl:when test="string-length(.)!=0">
				<xsl:value-of select="."/>
			</xsl:when>
			<xsl:otherwise>[<xsl:value-of select="name()"/>]</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
</xsl:stylesheet>
