--
-- SQL loader for AMI/IM2 database
-- Generated automatically at 070226-155035
--
-- To create the tables, connect to a database
-- and run this file within an SQL interpreter.
-- For PostgreSQL, execute initdb, postmaster, createdb,
-- then connect with psql and run "\i db_loader.sql"
--
-- CAUTION: this will erase existing tables with same names.

--
-- Create/load table: abstractive
--

DROP TABLE abstractive;

CREATE TABLE abstractive( meeting_id text NOT NULL,
 annotator text NOT NULL,
 paragraph_type text NOT NULL,
 sentence_number integer NOT NULL,
 sentence text
 );

COPY abstractive FROM 'abstractive.tsv' using delimiters '\t' ;

ALTER TABLE ONLY abstractive ADD CONSTRAINT abstractive_pkey PRIMARY KEY ( meeting_id, annotator, sentence_number );

--
-- Create/load table: summlink
--

DROP TABLE summlink;

CREATE TABLE summlink( meeting_id text NOT NULL,
 annotator text NOT NULL,
 speaker_id text NOT NULL,
 nxt_speaker text,
 da_annotator text NOT NULL,
 da_id integer NOT NULL,
 abs_annotator text NOT NULL,
 sentence_number integer NOT NULL
 );

COPY summlink FROM 'summlink.tsv' using delimiters '\t' ;

ALTER TABLE ONLY summlink ADD CONSTRAINT summlink_pkey PRIMARY KEY ( meeting_id, annotator, speaker_id, da_annotator, da_id, abs_annotator, sentence_number );

--
-- Create/load table: headGesture
--

DROP TABLE headGesture;

CREATE TABLE headGesture( meeting_id text NOT NULL,
 speaker_id text NOT NULL,
 nxt_speaker text,
 head_gesture_id integer,
 annotator text NOT NULL,
 starttime double precision,
 endtime double precision,
 head_gesture_type text,
 head_gesture_form text
 );

COPY headGesture FROM 'headGesture.tsv' using delimiters '\t' ;

ALTER TABLE ONLY headGesture ADD CONSTRAINT headGesture_pkey PRIMARY KEY ( meeting_id, speaker_id, head_gesture_id, annotator );

--
-- Create/load table: discussions
--

DROP TABLE discussions;

CREATE TABLE discussions( 
 meeting_id text NOT NULL,
 annotator text NOT NULL,
 discussion_id integer NOT NULL,
 discussion_name text,
 sync_speaker_id text NOT NULL,
 sync_nxt_speaker text,
 sync_annotator text NOT NULL,
 sync_id integer NOT NULL );

COPY discussions FROM 'discussions.tsv' using delimiters '\t' ;

ALTER TABLE ONLY discussions ADD CONSTRAINT discussions_pkey PRIMARY KEY ( meeting_id, annotator, discussion_id, sync_speaker_id, sync_annotator, sync_id );

--
-- Create/load table: focus
--

DROP TABLE focus;

CREATE TABLE focus( meeting_id text NOT NULL,
 speaker_id text NOT NULL,
 nxt_speaker text,
 foa_id integer NOT NULL,
 annotator text NOT NULL,
 starttime double precision,
 endtime double precision,
 what_type text,
 what_id text,
 what_nxt text,
 what_role text
 );

COPY focus FROM 'focus.tsv' using delimiters '\t' ;

ALTER TABLE ONLY focus ADD CONSTRAINT focus_pkey PRIMARY KEY ( meeting_id, speaker_id, foa_id, annotator );

--
-- Create/load table: segments
--

DROP TABLE segments;

CREATE TABLE segments( 
 meeting_id text NOT NULL,
 speaker_id text NOT NULL,
 nxt_speaker text,
 segment_id integer NOT NULL,
 annotator text NOT NULL,
 starttime double precision,
 endtime double precision,
 channel text,
 startword integer,
 endword integer,
 words text
 );

COPY segments FROM 'segments.tsv' using delimiters '\t' ;

ALTER TABLE ONLY segments ADD CONSTRAINT segments_pkey PRIMARY KEY ( meeting_id, speaker_id, segment_id, annotator );

--
-- Create/load table: words
--

DROP TABLE words;

CREATE TABLE words( 
 meeting_id text NOT NULL,
 speaker_id text NOT NULL,
 nxt_speaker text,
 item_id integer NOT NULL,
 annotator text NOT NULL,
 type text NOT NULL,
 content text,
 truncated text,
 mispronounced text,
 pronunciation text,
 starttime double precision,
 endtime double precision
 );

COPY words FROM 'words.tsv' using delimiters '\t' ;

ALTER TABLE ONLY words ADD CONSTRAINT words_pkey PRIMARY KEY ( meeting_id, speaker_id, item_id, annotator );

--
-- Create/load table: argumentationrels
--

DROP TABLE argumentationrels;

CREATE TABLE argumentationrels( 
 meeting_id text NOT NULL,
 annotator text NOT NULL,
 ar_id integer NOT NULL,
 ar_type text NOT NULL,
 ar_gloss text,
 src_speaker_id text NOT NULL,
 src_nxt_speaker text,
 src_annotator text NOT NULL,
 src_id integer NOT NULL,
 trg_speaker_id text NOT NULL,
 trg_nxt_speaker text,
 trg_annotator text NOT NULL,
 trg_id integer NOT NULL
 );

COPY argumentationrels FROM 'argumentationrels.tsv' using delimiters '\t' ;

ALTER TABLE ONLY argumentationrels ADD CONSTRAINT argumentationrels_pkey PRIMARY KEY (  meeting_id, annotator, ar_id, src_speaker_id, src_annotator, src_id, trg_speaker_id, trg_id  );

--
-- Create/load table: adjacencyPairs
--

DROP TABLE adjacencyPairs;

CREATE TABLE adjacencyPairs( meeting_id text NOT NULL,
 annotator text NOT NULL,
 ap_id integer NOT NULL,
 ap_type text,
 ap_type_gloss text,
 source_speaker_id text,
 source_nxt_speaker text,
 source_annotator text,
 source_da_id integer,
 target_speaker_id text,
 target_nxt_speaker text,
 target_annotator text,
 target_da_id integer
 );

COPY adjacencyPairs FROM 'adjacencyPairs.tsv' using delimiters '\t' ;

ALTER TABLE ONLY adjacencyPairs ADD CONSTRAINT adjacencyPairs_pkey PRIMARY KEY ( meeting_id, annotator, ap_id );

--
-- Create/load table: participantSummaries
--

DROP TABLE participantSummaries;

CREATE TABLE participantSummaries( meeting_id text NOT NULL,
 speaker_id text NOT NULL,
 nxt_speaker text,
 speaker_role text,
 paragraph_type text NOT NULL,
 sentence_number integer NOT NULL,
 sentence text
 );

COPY participantSummaries FROM 'participantSummaries.tsv' using delimiters '\t' ;

ALTER TABLE ONLY participantSummaries ADD CONSTRAINT participantSummaries_pkey PRIMARY KEY ( meeting_id, speaker_id, sentence_number );

--
-- Create/load table: handGesture
--

DROP TABLE handGesture;

CREATE TABLE handGesture( meeting_id text NOT NULL,
 speaker_id text NOT NULL,
 nxt_speaker text,
 hand_gesture_id integer,
 annotator text NOT NULL,
 starttime double precision,
 endtime double precision,
 hand_gesture_type text
 );

COPY handGesture FROM 'handGesture.tsv' using delimiters '\t' ;

ALTER TABLE ONLY handGesture ADD CONSTRAINT handGesture_pkey PRIMARY KEY ( meeting_id, speaker_id, hand_gesture_id, annotator );

--
-- Create/load table: topics
--

DROP TABLE topics;

CREATE TABLE topics( meeting_id text NOT NULL,
 topic_id integer NOT NULL,
 annotator text NOT NULL,
 depth integer,
 starttime double precision,
 endtime double precision,
 scenario_topic_type text,
 other_description text
 );

COPY topics FROM 'topics.tsv' using delimiters '\t' ;

ALTER TABLE ONLY topics ADD CONSTRAINT topics_pkey PRIMARY KEY ( meeting_id, topic_id, annotator );

--
-- Create/load table: dialogueActs
--

DROP TABLE dialogueActs;

CREATE TABLE dialogueActs( 
 meeting_id text NOT NULL,
 speaker_id text NOT NULL,
 nxt_speaker text,
 da_id integer NOT NULL,
 annotator text NOT NULL,
 da_name text,
 da_gloss text,
 starttime double precision,
 endtime double precision,
 startword integer,
 endword integer,
 words text
 );

COPY dialogueActs FROM 'dialogueActs.tsv' using delimiters '\t' ;

ALTER TABLE ONLY dialogueActs ADD CONSTRAINT dialogueActs_pkey PRIMARY KEY ( meeting_id, speaker_id, da_id, annotator );

--
-- Create/load table: namedEntities
--

DROP TABLE namedEntities;

CREATE TABLE namedEntities( 
 meeting_id text NOT NULL,
 speaker_id text NOT NULL,
 nxt_speaker text,
 ne_id integer NOT NULL,
 annotator text NOT NULL,
 ne_type text NOT NULL,
 ne_abbrev text,
 ne_keystroke text,
 starttime double precision,
 endtime double precision,
 startword integer,
 endword integer,
 words text
 );

COPY namedEntities FROM 'namedEntities.tsv' using delimiters '\t' ;

ALTER TABLE ONLY namedEntities ADD CONSTRAINT namedEntities_pkey PRIMARY KEY ( meeting_id, speaker_id, ne_id, annotator );

--
-- Create/load table: extractive
--

DROP TABLE extractive;

CREATE TABLE extractive( meeting_id text NOT NULL,
 annotator text NOT NULL,
 orig_pos integer,
 speaker_id text NOT NULL,
 nxt_speaker text,
 da_annotator text NOT NULL,
 da_id integer
 );

COPY extractive FROM 'extractive.tsv' using delimiters '\t' ;

ALTER TABLE ONLY extractive ADD CONSTRAINT extractive_pkey PRIMARY KEY ( meeting_id, annotator, orig_pos, speaker_id, da_id );

--
-- Create/load table: argumentstructs
--

DROP TABLE argumentstructs;

CREATE TABLE argumentstructs( 
 meeting_id text NOT NULL,
 speaker_id text NOT NULL,
 nxt_speaker text,
 annotator text NOT NULL,
 ae_id integer NOT NULL,
 ae_type text NOT NULL,
 ae_gloss text,
 starttime double precision,
 endtime double precision,
 startword integer,
 endword integer,
 words text
 );

COPY argumentstructs FROM 'argumentstructs.tsv' using delimiters '\t' ;

ALTER TABLE ONLY argumentstructs ADD CONSTRAINT argumentstructs_pkey PRIMARY KEY ( meeting_id, speaker_id, ae_id, annotator );

