<?xml version="1.0" encoding="UTF-8"?>
<!--
This stylesheet creates a table gathering all the segments grouped as discussions in files: XX1234z.discussions.xml.
Inspired from segments.xslt, and a bit from topics.xslt.
Caution, this file does not replace segment_id with the respective words (pointers are not fully solved).
To retrieve the actual words, a DB join is necessary between this table (= discussion.tsv) and the segments table (= sync).
Format of the table: 
		meeting_id, annotator, discussion_id, discussion_name, sync_speaker_id, sync_nxt_speaker, sync_annotator, sync_id
Example of source file (processed by this stylesheet)
		discussion-fragment nite:id="ES2002a.discussions.Erik.4" name="ES2002a - Remote functionality"
			nite:child href="ES2002a.D.segments.xml#id(ES2002a.sync.470)"
			nite:child href="ES2002a.B.segments.xml#id(ES2002a.sync.202)..id(ES2002a.sync.206)"
			...
Andrei Popescu-Belis, Feb 2007
*************************************
-->
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:nite="http://nite.sourceforge.net/">
	<xsl:output method="text" version="1.0" encoding="ISO-8859-1" indent="no"/>
	<xsl:param name="speakerfile">file://C:\Documents and Settings\Andrei Popescu-Belis\Mes documents\IM2phase2\DATA\AMI-data-020207\corpusResources\meetings.xml</xsl:param>
	<xsl:param name="speakerlist" select="document($speakerfile)"/>
	<xsl:param name="segmentspath">file://C:\Documents and Settings\Andrei Popescu-Belis\Mes documents\IM2phase2\DATA\AMI-data-020207\segments\</xsl:param>

<!-- ************************************************ -->
	<xsl:template match="nite:root">
		<xsl:param name="meeting_id" select="substring-before(@nite:id,'.')"/>
		<xsl:param name="meeting_speakers2" select="$speakerlist//meeting[@observation = $meeting_id]"/>
		<xsl:apply-templates select="//nite:child">
			<xsl:with-param name="meeting_speakers" select="$meeting_speakers2"/>
		</xsl:apply-templates>
	</xsl:template>
<!-- ************************************************ -->	
	<xsl:template match="nite:child">
		<xsl:param name="meeting_speakers"/>
		<!-- Need to test from the beginning whether it points to one sync or to a range of syncs (with ..) 
			because in the second case a line has to be created for each sync.  Also in this case, one
			has to go through the segments in the 'segments' file so the first part of the line has to be 
			passed as a parameter ($almost_all_the_line).-->
		<xsl:param name="disc_id" select="../@nite:id"/> 	<!-- example ES2002a.discussions.Erik.4 -->
		<xsl:param name="meeting_id" select="substring-before($disc_id,'.')"/>
		<xsl:param name="annotator" select="substring-before(substring-after(substring-after($disc_id,'.'),'.'),'.')"/>
		<xsl:param name="discussion_id" select="substring-after(substring-after(substring-after($disc_id,'.'),'.'),'.')"/>
		<xsl:param name="discussion_name" select="../@name"/>
		<xsl:param name="nxt_speaker" select="substring-before(substring-after(@href,'.'),'.')"/>
		<xsl:param name="sync_speaker_id" select="$meeting_speakers/speaker[@nxt_agent = $nxt_speaker]/@global_name"/>
		<xsl:param name="sync_nxt_speaker" select="$nxt_speaker"/>
		<xsl:param name="sync_annotator">AMIdefault</xsl:param> <!-- here one could find the annotator, if there was one -->
		<xsl:param name="start_sync" select="substring-before(substring-after(substring-after(substring-after(@href,'#id'),'.'),'.'),')')"/>
			<!-- this param also works for sync_id in case there is one_sync only -->
		<xsl:param name="end_sync" select="substring-before(substring-after(substring-after(substring-after(@href,'..id'),'.'),'.'),')')"/>
			<!-- this parameter does not make sense in the first case, but must be put it here -->
		<xsl:choose>
			<xsl:when test="not(contains(@href,'..'))">
				<xsl:call-template name="one_sync"> <!-- tab: '&#x09;'-->
					<xsl:with-param name="almost_all_the_line" 
					select="concat($meeting_id, '&#x09;', $annotator, '&#x09;', $discussion_id, '&#x09;', $discussion_name, '&#x09;', $sync_speaker_id, '&#x09;', $sync_nxt_speaker, '&#x09;', $sync_annotator, '&#x09;', translate($start_sync,',',''))"/> 
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise> <!-- go through all the syncs that are in range -->
				<xsl:for-each select="document(concat($segmentspath,substring-before(@href,'#id')))/nite:root/segment[(substring-after(substring-after(@nite:id,'.'),'.') &gt;= $start_sync) and (substring-after(substring-after(@nite:id,'.'),'.') &lt;= $end_sync)]">
					<xsl:call-template name="range_of_sync">
						<xsl:with-param name="sync_id" select="translate(substring-after(substring-after(@nite:id,'.'),'.'),',','')"/>
						<xsl:with-param name="almost_all_the_line" 
						select="concat($meeting_id, '&#x09;', $annotator, '&#x09;', $discussion_id, '&#x09;', $discussion_name, '&#x09;', $sync_speaker_id, '&#x09;', $sync_nxt_speaker, '&#x09;', $sync_annotator)"/>
					</xsl:call-template>
				</xsl:for-each>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<!-- ************************************************ -->	
	<xsl:template name="one_sync">
		<xsl:param name="almost_all_the_line" select="dummy"/>
		<xsl:value-of select="$almost_all_the_line"/>
		<xsl:text>&#xA;</xsl:text>
	</xsl:template>
	<!-- ************************************************ -->
	<xsl:template name="range_of_sync">
		<xsl:param name="sync_id" select="dummy"/>
		<xsl:param name="almost_all_the_line" select="dummy"/>
		<xsl:value-of select="$almost_all_the_line"/>
		<xsl:text>	</xsl:text>
		<xsl:value-of select="$sync_id"/>
		<xsl:text>&#xA;</xsl:text>
	</xsl:template>
	<!-- ************************************************ -->		
</xsl:stylesheet>
