<?xml version="1.0" encoding="UTF-8"?>
<!-- *************************************
This stylesheet creates a table corresponding to the annotation of extractive summaries.
The only external files to be used are the ones with the speaker codes.
Format of the table: meeting_id, annotator, orig_pos, speaker_id, nxt_speaker, da_annotator, da_id.
A bit tricky to build because NXT format sometimes uses intervals such as dialog-act.26..dialog-act.33 
which must be converted into a series of lines (hence the recursive call of the 'write_line' template..
The orig_pos (original position) is necessary, otherwise the ordering of the dialog-acts (cross-speaker) 
will be lost in the database, although it could be inferred by looking for the start times of each utterance.
However, dialog acts described by an interval (dialog-act.26..dialog-act.37) will have the same orig_pos. 
Andrei Popescu-Belis, June 2006
****************************************-->
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:nite="http://nite.sourceforge.net/">
	<xsl:output method="text" version="1.0" encoding="ISO-8859-1" indent="no"/>
	<xsl:param name="speakerfile">file://C:\Documents and Settings\Andrei Popescu-Belis\Mes documents\IM2phase2\AMI-data-private\corpusResources\meetings.xml</xsl:param>
	<xsl:param name="speakerlist" select="document($speakerfile)"/>
	<!-- ************************************************ -->
	<xsl:template match="nite:root">
		<xsl:param name="meeting_id" select="substring-before(@nite:id,'.')"/>
		<xsl:param name="meeting_speakers2" select="$speakerlist//meeting[@observation = $meeting_id]"/>
		<xsl:apply-templates select="//nite:child">
			<xsl:with-param name="meeting_speakers" select="$meeting_speakers2"/>
		</xsl:apply-templates>
	</xsl:template>
	<!-- ************************************************ -->
	<xsl:template match="nite:child">
		<xsl:param name="meeting_speakers"/>
		<xsl:param name="href" select="substring-before(@href,'#')"/> <!-- sample : ES2003b.B.dialog-act.xml -->
		<xsl:param name="meeting_id" select="substring-before($href,'.')"/>
		<xsl:param name="annotator" select="substring-before(substring-after(substring-after(../@nite:id,'.'),'.'),'.')"/>
		<xsl:param name="speaker_id" select="$meeting_speakers/speaker[@nxt_agent = substring-before(substring-after($href,'.'),'.')]/@global_name"/>
		<xsl:param name="nxt_speaker" select="substring-before(substring-after($href,'.'),'.')"/>
		<xsl:param name="da_annotator" select="substring-before(substring-after(substring-after(substring-after(substring-after(@href,'#'),'.'),'.'),'.'),'.')"/>
		<xsl:choose>
			<xsl:when test="contains(@href,'..')">
				<xsl:call-template name="write_line">
					<xsl:with-param name="meeting_id" select="$meeting_id"/>
					<xsl:with-param name="annotator" select="$annotator"/>
					<xsl:with-param name="speaker_id" select="$speaker_id"/>
					<xsl:with-param name="nxt_speaker" select="$nxt_speaker"/>
					<xsl:with-param name="da_annotator" select="$da_annotator"/>
					<xsl:with-param name="start_da" select="substring-before(substring-after(substring-after(substring-after(substring-after(substring-after(@href,'#'),'.'),'.'),'.'),'.'),')..')"/>
					<xsl:with-param name="end_da"  select="substring-before(substring-after(substring-after(substring-after(substring-after(substring-after(@href,'..id'),'.'),'.'),'.'),'.'),')')"/>
				</xsl:call-template> 
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="write_line">
					<xsl:with-param name="meeting_id" select="$meeting_id"/>
					<xsl:with-param name="annotator" select="$annotator"/>
					<xsl:with-param name="speaker_id" select="$speaker_id"/>
					<xsl:with-param name="nxt_speaker" select="$nxt_speaker"/>
					<xsl:with-param name="da_annotator" select="$da_annotator"/>
					<xsl:with-param name="start_da" select="substring-before(substring-after(substring-after(substring-after(substring-after(substring-after(@href,'#'),'.'),'.'),'.'),'.'),')')"/>
					<xsl:with-param name="end_da"  select="substring-before(substring-after(substring-after(substring-after(substring-after(substring-after(@href,'#'),'.'),'.'),'.'),'.'),')')"/>
				</xsl:call-template>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<!-- ********************************************* -->
	<xsl:template name="write_line">
		<xsl:param name="meeting_id"/>
		<xsl:param name="annotator"/>
		<xsl:param name="speaker_id"/>
		<xsl:param name="nxt_speaker"/>
		<xsl:param name="da_annotator"/>
		<xsl:param name="start_da"/>
		<xsl:param name="end_da"/>
		<!-- meeting_id -->
		<xsl:value-of select="$meeting_id"/>
		<xsl:text>	</xsl:text>
		<!-- annotator -->
		<xsl:value-of select="$annotator"/>
		<xsl:text>	</xsl:text>
		<!-- orig_pos -->
		<xsl:value-of select="position()"/>
		<xsl:text>	</xsl:text>
		<!-- speaker_id -->
		<xsl:value-of select="$speaker_id"/>
		<xsl:text>	</xsl:text>
		<!-- nxt_speaker -->
		<xsl:value-of select="$nxt_speaker"/>
		<xsl:text>	</xsl:text>
		<!-- da_annotator -->
		<xsl:value-of select="$da_annotator"/>
		<xsl:text>	</xsl:text>
		<!-- da_id -->
		<xsl:value-of select="$start_da"/>
		<xsl:text>
</xsl:text>
		<xsl:if test="$start_da &lt; $end_da">
			<xsl:call-template name="write_line">
				<xsl:with-param name="meeting_id" select="$meeting_id"/>
				<xsl:with-param name="annotator" select="$annotator"/>
				<xsl:with-param name="speaker_id" select="$speaker_id"/>
				<xsl:with-param name="nxt_speaker" select="$nxt_speaker"/>
				<xsl:with-param name="da_annotator" select="$da_annotator"/>
				<xsl:with-param name="start_da" select="$start_da + 1"/>
				<xsl:with-param name="end_da" select="$end_da"/>
			</xsl:call-template>
		</xsl:if>
	</xsl:template>
</xsl:stylesheet>
