<?xml version="1.0" encoding="UTF-8"?>
<!-- *************************************
This stylesheet creates a table corresponding to the links between dialog acts included in extractive summaries and the sentence they support in abstractive summaries.
It appears that the links are always 1:1.
The only external files to be used are the ones with the speaker codes.
Format of the table: meeting_id, annotator, speaker_id, nxt_speaker, da_annotator, da_id, abs_annotator, sentence_number
****************************************
EXAMPLE
 summlink nite:id="ES2002a.summlink.dharshi.1"
    nite:pointer role="extractive"  href="ES2002a.B.dialog-act.xml#id(ES2002a.B.dialog-act.dharshi.3)"
    nite:pointer role="abstractive"  href="ES2002a.abssumm.xml#id(ES2002a.rdhillon.s.1)"
***************************************
Andrei Popescu-Belis, Feb 2007
-->
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:nite="http://nite.sourceforge.net/">
	<xsl:output method="text" version="1.0" encoding="ISO-8859-1" indent="no"/>
	<xsl:param name="speakerfile">file://C:\Documents and Settings\Andrei Popescu-Belis\Mes documents\IM2phase2\DATA\AMI-data-020207\corpusResources\meetings.xml</xsl:param>
	<xsl:param name="speakerlist" select="document($speakerfile)"/>

	<!-- ************************************************ -->
	<xsl:template match="nite:root">
		<xsl:param name="meeting_id" select="substring-before(@nite:id,'.')"/>
		<xsl:apply-templates select="//summlink">
			<xsl:with-param name="meeting_speakers" select="$speakerlist//meeting[@observation = $meeting_id]"/>
		</xsl:apply-templates>
	</xsl:template>
	<!-- ************************************************ -->
	<xsl:template match="summlink">
		<xsl:param name="meeting_speakers"/>
		<!-- meeting_id -->
		<xsl:value-of select="substring-before(@nite:id,'.')"/>
		<xsl:text>	</xsl:text>
		<!-- annotator -->
		<xsl:value-of select="substring-before(substring-after(substring-after(@nite:id,'.'),'.'),'.')"/>
		<xsl:text>	</xsl:text>
		<xsl:apply-templates select="nite:pointer[@role='extractive']" mode="extractive">
			<xsl:with-param name="meeting_speakers" select="$meeting_speakers"/>
		</xsl:apply-templates>
		<xsl:apply-templates select="nite:pointer[@role='abstractive']" mode="abstractive"/>
			<xsl:text>
</xsl:text>
	</xsl:template>
	
	<xsl:template match="nite:pointer" mode="extractive">
		<xsl:param name="meeting_speakers"/>
		<xsl:param name="meeting_id" select="substring-before(@href,'.')"/>
		<xsl:param name="nxt_speaker" select="substring-before(substring-after(@href,'.'),'.')"/>
		<xsl:param name="speaker_id" select="$meeting_speakers/speaker[@nxt_agent = $nxt_speaker]/@global_name"/>
		<!-- speaker_id -->
		<xsl:value-of select="$speaker_id"/>
		<xsl:text>	</xsl:text>
		<!-- nxt_speaker -->
		<xsl:value-of select="$nxt_speaker"/>
		<xsl:text>	</xsl:text>
		<!-- da_annotator -->
		<xsl:value-of select="substring-before(substring-after(substring-after(substring-after(substring-after(@href,'#id'),'.'),'.'),'.'),'.')"/>
		<xsl:text>	</xsl:text>
		<!-- da_id -->
		<xsl:value-of select="substring-before(substring-after(substring-after(substring-after(substring-after(substring-after(@href,'#id'),'.'),'.'),'.'),'.'),')')"/>
		<xsl:text>	</xsl:text>
	</xsl:template>
	
	<xsl:template match="nite:pointer" mode="abstractive">
		<!-- abs_annotator -->
		<xsl:value-of select="substring-before(substring-after(substring-after(@href,'#id'),'.'),'.')"/>
		<xsl:text>	</xsl:text>
		<!-- sentence_number -->
		<xsl:value-of select="substring-before(substring-after(substring-after(substring-after(substring-after(@href,'#id'),'.'),'.'),'.'),')')"/>
	</xsl:template>
	
	<!-- ********************************************* -->
</xsl:stylesheet>
