<?xml version="1.0" encoding="UTF-8"?>
<!-- This stylesheet creates a table corresponding to the hierarchy of (cross-channel) topical episodes using the files: XX1234z.topics.xml -->
<!-- The table uses only the temporal indications of an episode, assuming that in the XX1234z.topics.xml files the series of words are grouped chronologically into episodes. -->
<!-- Note that the beginning/end time of an episode are an approximation based on forced-alignment timing of the words. -->
<!-- To include information about the hierarchical structure, the depth of each episode is recorded (this is sufficient to reconstruct the hierarchy) -->
<!-- Format of the table: meeting_id, topic_id, annotator, depth, starttime, endtime, scenario_topic_type, other_description -->
<!-- Andrei Popescu-Belis, June 2006 -->
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:nite="http://nite.sourceforge.net/">
	<xsl:output method="text" version="1.0" encoding="ISO-8859-1" indent="no"/>
	<xsl:param name="wordfilepath">file://C:\Documents and Settings\Andrei Popescu-Belis\Mes documents\IM2phase2\DATA\AMI-data-020207\words\</xsl:param>
	<xsl:param name="defaulttopicsfile">file://C:\Documents and Settings\Andrei Popescu-Belis\Mes documents\IM2phase2\DATA\AMI-data-020207\ontologies\default-topics.xml</xsl:param>
	<xsl:param name="defaulttopics" select="document($defaulttopicsfile)"/>	
	<!-- ************************************************ -->
	<xsl:template match="nite:root">
		<xsl:apply-templates select="//topic"/>
	</xsl:template>
	<!-- ************************************************ -->
	<xsl:template match="topic">
		<xsl:param name="topicref" select="substring-before(substring-after(.//nite:pointer[(@role='scenario_topic_type')]/@href,'#id('),')')"/>
		<!-- meeting_id -->
		<xsl:value-of select="substring-before(@nite:id,'.topic')"/> <!-- sample id: ES2003a.topic.rdhillon.5 -->
		<xsl:text>	</xsl:text>
		<!-- topic_id -->
		<xsl:value-of select="substring-after(substring-after(@nite:id,'topic.'),'.')"/>
		<xsl:text>	</xsl:text>
		<!-- annotator -->
		<xsl:value-of select="substring-before(substring-after(@nite:id,'topic.'),'.')"/>
		<xsl:text>	</xsl:text>
		<!-- depth -->
		<xsl:value-of select="count(ancestor-or-self::topic)"/>
		<xsl:text>	</xsl:text>
		<!-- starttime --> 		
		<xsl:choose>
			<xsl:when test="contains(.//nite:child[position()=1]/@href,'..')">
				<xsl:call-template name="getstarttime">
					<xsl:with-param name="start" select="substring-before(substring-after(.//nite:child[position()=1]/@href,'#id('),')..')"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="getstarttime">
					<xsl:with-param name="start" select="substring-before(substring-after(.//nite:child[position()=1]/@href,'#id('),')')"/>
				</xsl:call-template>
			</xsl:otherwise>
		</xsl:choose>
		<!-- endtime -->
		<xsl:choose>
			<xsl:when test="contains(.//nite:child[last()]/@href,'..')">
				<xsl:call-template name="getendtime">
					<xsl:with-param name="end" select="substring-before(substring-after(.//nite:child[last()]/@href,'..id('),')')"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="getendtime">
					<xsl:with-param name="end" select="substring-before(substring-after(.//nite:child[last()]/@href,'#id('),')')"/>
				</xsl:call-template>
			</xsl:otherwise>
		</xsl:choose>
		<!-- scenario_topic_type -->
		<xsl:value-of select="$defaulttopics//topicname[@nite:id=$topicref]/@name"/><xsl:text>	</xsl:text>
		<!-- other_description -->	
		<xsl:choose>
			<xsl:when test="@other_description"><xsl:value-of select="@other_description"/></xsl:when>
			<xsl:otherwise>none</xsl:otherwise>
		</xsl:choose>
		<xsl:text>
</xsl:text>
	</xsl:template>
	<!-- ************************************************ -->
	<xsl:template name="getstarttime">
		<xsl:param name="start"/>
		<!--xsl:value-of select="$start"/>
		<xsl:text>	</xsl:text-->
		<xsl:value-of select="document(concat($wordfilepath,substring-before($start,'words'),'words.xml'))//*[$start=@nite:id]/@starttime"/>
		<xsl:text>	</xsl:text>
	</xsl:template>
	<!-- ************************************************ -->
	<xsl:template name="getendtime">
		<xsl:param name="end"/>
		<!--xsl:value-of select="$end"/>
		<xsl:text>	</xsl:text-->
		<xsl:value-of select="document(concat($wordfilepath,substring-before($end,'words'),'words.xml'))//*[$end=@nite:id]/@endtime"/>
		<xsl:text>	</xsl:text>
	</xsl:template>
	<!-- ************************************************ -->
		<xsl:template match="w|disfmarker|vocalsound|gap">
		<xsl:choose>
			<xsl:when test="position()=1"/>
			<xsl:otherwise><xsl:text> </xsl:text></xsl:otherwise>
		</xsl:choose>
		<xsl:choose>
			<xsl:when test="string-length(.)!=0"><xsl:value-of select="."/></xsl:when>
			<xsl:otherwise>[<xsl:value-of select="name()"/>]</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
</xsl:stylesheet>
