<?xml version="1.0" encoding="UTF-8"?>
<!-- This stylesheet creates a table corresponding to the transcribed words from the dialogues,
      including also disfluency markers, vocal sounds and gaps. Example:
		<nite:root nite:id="EN2001a.A.words" xmlns:nite="http://nite.sourceforge.net/"> ...
			<w nite:id="EN2001a.A.words536">yet</w>
			<w nite:id="EN2001a.A.words537" punc="true">.</w>
			<vocalsound nite:id="EN2001a.A.words538" type="laugh"/>
      Format of the table (words.tsv): 
      meeting_id, speaker_id, nxt_speaker, item_id, annotator, type, content, truncated, mispronounced, pronunciation, starttime, endtime
      Where 	type={word,punctuation,disfmarker,vocalsound,gap}, 
	  For 'word' only:
					content=(the word, or punctuation, or type of vocal sound, or none}, 
					truncated={true,''} ('' is default) (only possible markup: trunc="true")
					mispronounced={'',true} ('' is default) (only possible markup: mispronounced="true")
					pronunciation={foreign,''} ('' is default) (only possible markup: pron="foreign") [this applies also to gap!]
	  No 'comment' 'nonvocalsound' or 'pause' are used in words.xml. 
	'starttime' and 'endtime' aren't always available (they're given 0 value in this case, otherwise PSQL complains about "" as a number.
	'trunc' and 'mispronounced' appear only 6 times together. 'mispronounced' and 'pron' appear only once together (we could spare one column!).
      *******************************************
      Andrei Popescu-Belis, February 2007 -->
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:nite="http://nite.sourceforge.net/">
	<xsl:output method="text" version="1.0" encoding="ISO-8859-1" indent="no"/>
	<xsl:param name="speakerfile">file://C:\Documents and Settings\Andrei Popescu-Belis\Mes documents\IM2phase2\DATA\AMI-data-020207\corpusResources\meetings.xml</xsl:param>
	<xsl:param name="speakerlist" select="document($speakerfile)"/>
	<!-- ************************************************ -->
	<xsl:template match="nite:root">
		<xsl:param name="meeting_id" select="substring-before(@nite:id,'.')"/>
		<xsl:param name="meeting_speakers2" select="$speakerlist//meeting[@observation = $meeting_id]"/>
		<xsl:apply-templates select="*">
			<xsl:with-param name="meeting_speakers" select="$meeting_speakers2"/>
		</xsl:apply-templates>
	</xsl:template>
	<!-- ************************************************ -->
	<xsl:template match="w|disfmarker|vocalsound|gap">
		<!-- let's call these 'items' -->
		<xsl:param name="meeting_speakers"/>
		<xsl:param name="nxt_agent" select="substring-before(substring-after(@nite:id,'.'),'.')"/>
		<!-- nite:id example: EN2001a.A.words536 -->
		<!-- meeting_id -->
		<xsl:value-of select="substring-before(@nite:id,'.')"/>
		<xsl:text>	</xsl:text>
		<!-- speaker_id -->
		<xsl:value-of select="$meeting_speakers/speaker[@nxt_agent = $nxt_agent]/@global_name"/>
		<xsl:text>	</xsl:text>
		<!-- nxt_speaker -->
		<xsl:value-of select="substring-before(substring-after(@nite:id,'.'),'.')"/>
		<xsl:text>	</xsl:text>
		<!-- item_id -->
		<xsl:value-of select="substring-after(@nite:id,'words')"/>
		<xsl:text>	</xsl:text>
		<!-- annotator -->
		<!-- xsl:value-of select="substring-before(substring-after(substring-after(substring-after(@nite:id,'.'),'.'),'.'),'.')"/ -->
		<xsl:text>AMIdefault	</xsl:text>
		<!-- type -->
		<xsl:choose>
			<xsl:when test="(name()='w') and (@punc='true')"><xsl:text>punctuation</xsl:text></xsl:when>
			<xsl:when test="(name()='w')"><xsl:text>word</xsl:text></xsl:when>			
			<xsl:otherwise><xsl:value-of select="name()"/></xsl:otherwise>
		</xsl:choose>
		<xsl:text>	</xsl:text>
		<!-- content -->
		<xsl:choose>
			<xsl:when test="string-length(.)!=0">
				<xsl:value-of select="."/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="@type"/>
			</xsl:otherwise>
		</xsl:choose>
		<xsl:text>	</xsl:text>
		<!-- truncated -->
		<xsl:value-of select="@trunc"/>
		<xsl:text>	</xsl:text>
		<!-- mispronounced -->
		<xsl:value-of select="@mispronounced"/>
		<xsl:text>	</xsl:text>
		<!-- pronunciation -->
		<xsl:value-of select="@pron"/>
		<xsl:text>	</xsl:text>
		<!-- starttime -->
		<xsl:choose>
			<xsl:when test="@starttime">
				<xsl:value-of select="@starttime"/>
			</xsl:when>
			<xsl:otherwise>0</xsl:otherwise>
		</xsl:choose>
		<xsl:text>	</xsl:text>
		<!-- endtime -->
		<xsl:choose>
			<xsl:when test="@endtime">
				<xsl:value-of select="@endtime"/>
			</xsl:when>
			<xsl:otherwise>0</xsl:otherwise>
		</xsl:choose>
		<xsl:text>&#xA;</xsl:text>
	</xsl:template>
	<!-- ************************************************ -->
</xsl:stylesheet>
